@@ -413,8 +413,11 @@ gconf_editor_popup_window_unset_key (GtkAction *action, GtkWidget *callback_data
 	gchar *key;
 	GError *error = NULL;
 	
-	gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view)),
-					 NULL, &iter);
+	if (!gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view)),
+					 NULL, &iter)) {
+		return;
+	}
+
 	gtk_tree_model_get (window->sorted_list_model, &iter,
 			    GCONF_LIST_MODEL_KEY_PATH_COLUMN, &key,
 			    -1);
@@ -742,7 +745,7 @@ static GtkActionEntry entries[] = {
 	
 	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1", N_("Open the help contents for the Configuration Editor"), 
 	  G_CALLBACK (help_cb) },
-	{ "AboutAction", GNOME_STOCK_ABOUT, N_("_About"), NULL, N_("Show the about dialog for the Configuration Editor"), 
+	{ "AboutAction", GTK_STOCK_ABOUT, N_("_About"), NULL, N_("Show the about dialog for the Configuration Editor"), 
 	  G_CALLBACK (gconf_editor_window_about_window) },
 
 	{ "NewKey", GTK_STOCK_NEW, N_("_New Key..."), "<control>N", N_("Create a new key"),
@@ -896,6 +899,10 @@ list_view_button_press_event (GtkTreeView *tree_view, GdkEventButton *event, GCo
 						  TRUE);
 			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
 						  TRUE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
+						  TRUE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
+						  TRUE);
 			
 			gtk_tree_path_free (path);
 		}
@@ -904,6 +911,10 @@ list_view_button_press_event (GtkTreeView *tree_view, GdkEventButton *event, GCo
 						  FALSE);
 			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
 						  FALSE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
+						  FALSE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
+						  FALSE);
 
 		}
 		
@@ -980,6 +991,33 @@ gconf_editor_window_list_view_popup_position (GtkMenu   *menu G_GNUC_UNUSED,
 static void
 gconf_editor_window_list_view_popup_menu (GtkWidget *widget, GConfEditorWindow *window)
 {
+	GtkTreeIter iter;
+
+	GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view));
+	/* Select our row */
+	if (gtk_tree_selection_get_selected (selection, &window->list_model, &iter)) {
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/EditKey"), 
+					  TRUE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
+					  TRUE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
+					  TRUE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
+					  TRUE);
+			
+	}
+	else {
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/EditKey"), 
+					  FALSE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
+					  FALSE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
+					  FALSE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
+					  FALSE);
+
+	}
+	
 	gtk_menu_popup (GTK_MENU (window->popup_menu), NULL, NULL,
 			(GtkMenuPositionFunc) gconf_editor_window_list_view_popup_position, 
 			widget->window,
