@@ -32,9 +32,7 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtkcombobox.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtksizegroup.h>
 #include <gtk/gtkspinbutton.h>
@@ -60,17 +58,42 @@ enum
 
 
 static void
-option_menu_changed (GtkWidget *option_menu,
-		     GConfKeyEditor *editor)
+combo_box_changed (GtkWidget *combo_box,
+		   GConfKeyEditor *editor)
 {
 	int index;
 
-	index = gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu));
-	
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (editor->notebook),
-				       index);
+	index = gtk_combo_box_get_active (GTK_COMBO_BOX (combo_box));
 
 	editor->active_type = index;
+		
+	gtk_window_set_resizable (GTK_WINDOW (editor), FALSE);	
+	gtk_widget_hide (editor->int_box);
+	gtk_widget_hide (editor->bool_box);
+	gtk_widget_hide (editor->string_box);
+	gtk_widget_hide (editor->float_box);
+	gtk_widget_hide (editor->list_box);
+				       
+	switch (index) {
+		case EDIT_INTEGER:
+			gtk_widget_show_all (editor->int_box);
+			break;
+		case EDIT_BOOLEAN:
+			gtk_widget_show_all (editor->bool_box);
+			break;
+		case EDIT_STRING:
+			gtk_widget_show_all (editor->string_box);
+			break;
+  		case EDIT_FLOAT:
+			gtk_widget_show_all (editor->float_box);
+			break;
+		case EDIT_LIST:
+			gtk_window_set_resizable (GTK_WINDOW (editor), TRUE);
+			gtk_widget_show_all (editor->list_box);
+			break;
+		default:
+			g_assert_not_reached ();
+	}
 }
 
 static void
@@ -100,70 +123,60 @@ gconf_key_editor_list_entry_changed (GConfCellRenderer *cell, const gchar *path_
 }
 
 static void
-list_type_menu_changed (GtkWidget *option_menu,
+list_type_menu_changed (GtkWidget *combobox,
 			GConfKeyEditor *editor)
 {
 	gtk_list_store_clear (editor->list_model);
 }
 
 static GtkWidget *
-gconf_key_editor_create_option_menu (GConfKeyEditor *editor)
+gconf_key_editor_create_combo_box (GConfKeyEditor *editor)
 {
-	GtkWidget *option_menu, *menu;
+	GtkWidget *combo_box;
 
-	option_menu = gtk_option_menu_new ();
+	combo_box = gtk_combo_box_new_text ();
 
 	/* These have to be ordered so the EDIT_ enum matches the
 	 * menu indices
 	 */
-	menu = gtk_menu_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), 
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Integer"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), 
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Boolean"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), 
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("String"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), 
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Float"))));
- 	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("List"))));
-	gtk_widget_show_all (menu);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), (menu));
 
-	g_signal_connect (option_menu, "changed",
-			  G_CALLBACK (option_menu_changed),
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Integer"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Boolean"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("String"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Float"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("List"));
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 0);
+
+	g_signal_connect (combo_box, "changed",
+			  G_CALLBACK (combo_box_changed),
 			  editor);
 	
-	gtk_widget_show_all (option_menu);
-	return option_menu;
+	gtk_widget_show_all (combo_box);
+	return combo_box;
 }
 
 static GtkWidget *
 gconf_key_editor_create_list_type_menu (GConfKeyEditor *editor)
 {
-	GtkWidget *option_menu, *menu;
+	GtkWidget *combo_box;
 
-	option_menu = gtk_option_menu_new ();
+	combo_box = gtk_combo_box_new_text ();
 
 	/* These have to be ordered so the EDIT_ enum matches the
-	 * menu indices
+	 * combobox indices
 	 */
-	menu = gtk_menu_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Integer"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Boolean"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("String"))));
-	gtk_widget_show_all (menu);
-        gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), (menu));
 
-	g_signal_connect (option_menu, "changed",
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Integer"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Boolean"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("String"));
+
+	g_signal_connect (combo_box, "changed",
 			  G_CALLBACK (list_type_menu_changed),
 			  editor);
 
-        gtk_widget_show_all (option_menu);
-        return option_menu;
+        gtk_widget_show_all (combo_box);
+        return combo_box;
 }
 
 static void
@@ -208,36 +221,33 @@ list_add_clicked (GtkButton *button,
 		  GConfKeyEditor *editor)
 {
 	GtkWidget *dialog;
-	GtkWidget *hbox1, *hbox2;
-	GtkWidget *stock;
+	GtkWidget *hbox;
 	GtkWidget *value_widget;
 	GtkWidget *label;
 	gint response;
 	GtkTreeIter iter;
 	GtkTreeSelection *selection;
 
-	dialog = gtk_dialog_new_with_buttons (_("Add new list entry"),
+	dialog = gtk_dialog_new_with_buttons (_("Add New List Entry"),
                                               GTK_WINDOW (editor),
 					      GTK_DIALOG_MODAL| GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (editor)->vbox), 2);
 	
-	hbox1 = gtk_hbox_new (FALSE, 8);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox1), 8);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox1, FALSE, FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, FALSE, FALSE, 0);
 
-	stock = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
-	gtk_box_pack_start (GTK_BOX (hbox1), stock, FALSE, FALSE, 0);
+	label = gtk_label_new_with_mnemonic (_("_New list value:"));
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-	hbox2 = gtk_hbox_new (FALSE, 3);
-	gtk_box_pack_start (GTK_BOX (hbox1), hbox2, TRUE, TRUE, 0);
-
-	label = gtk_label_new_with_mnemonic (_("_New list element:"));
-	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
-
-	switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+	switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 		case EDIT_INTEGER:
 			value_widget = gtk_spin_button_new_with_range (G_MININT, G_MAXINT, 1);
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (value_widget), 0);
@@ -258,9 +268,9 @@ list_add_clicked (GtkButton *button,
 	}
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), value_widget);
-	gtk_box_pack_start (GTK_BOX (hbox2), value_widget, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), value_widget, TRUE, TRUE, 0);
 
-	gtk_widget_show_all (hbox1);
+	gtk_widget_show_all (hbox);
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -269,7 +279,7 @@ list_add_clicked (GtkButton *button,
 		
 	        value = NULL;
 
-		switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+		switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 			case EDIT_INTEGER:
 				value = gconf_value_new (GCONF_VALUE_INT);
 				gconf_value_set_int (value,
@@ -311,8 +321,7 @@ static void
 list_edit_element (GConfKeyEditor *editor)
 {
 	GtkWidget *dialog;
-	GtkWidget *hbox1, *hbox2;
-	GtkWidget *stock;
+	GtkWidget *hbox;
 	GtkWidget *value_widget;
 	GtkWidget *label;
 	gint response;
@@ -321,31 +330,29 @@ list_edit_element (GConfKeyEditor *editor)
 	GtkTreeModel *model;
 	GConfValue *value = NULL;
 
-	dialog = gtk_dialog_new_with_buttons (_("Edit list entry"),
+	dialog = gtk_dialog_new_with_buttons (_("Edit List Entry"),
                                               GTK_WINDOW (editor),
 					      GTK_DIALOG_MODAL| GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (editor)->vbox), 2);
 	
-	hbox1 = gtk_hbox_new (FALSE, 8);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox1), 8);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox1, FALSE, FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, FALSE, FALSE, 0);
 
-	stock = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
-	gtk_box_pack_start (GTK_BOX (hbox1), stock, FALSE, FALSE, 0);
-
-	hbox2 = gtk_hbox_new (FALSE, 3);
-	gtk_box_pack_start (GTK_BOX (hbox1), hbox2, TRUE, TRUE, 0);
-
-	label = gtk_label_new_with_mnemonic (_("_Edit list element:"));
-	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
+	label = gtk_label_new_with_mnemonic (_("_Edit list value:"));
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (editor->list_widget));
 	gtk_tree_selection_get_selected (selection, &model, &iter);
 	gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 0, &value, -1);
-	switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+	switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 		case EDIT_INTEGER:
 			value_widget = gtk_spin_button_new_with_range (G_MININT, G_MAXINT, 1);
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (value_widget), gconf_value_get_int (value));
@@ -365,9 +372,9 @@ list_edit_element (GConfKeyEditor *editor)
 	gconf_value_free (value);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), value_widget);
-	gtk_box_pack_start (GTK_BOX (hbox2), value_widget, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), value_widget, TRUE, TRUE, 0);
 
-	gtk_widget_show_all (hbox1);
+	gtk_widget_show_all (hbox);
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -376,7 +383,7 @@ list_edit_element (GConfKeyEditor *editor)
 		
 	        value = NULL;
 
-		switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+		switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 			case EDIT_INTEGER:
 				value = gconf_value_new (GCONF_VALUE_INT);
 				gconf_value_set_int (value,
@@ -532,7 +539,7 @@ gconf_key_editor_class_init (GConfKeyEditorClass *klass)
 static void
 gconf_key_editor_init (GConfKeyEditor *editor)
 {
-	GtkWidget *hbox, *frame, *framebox;
+	GtkWidget *hbox, *vbox, *framebox;
 	GtkWidget *label, *image;
 	GtkWidget *value_box;
 	GtkWidget *button_box, *button;
@@ -547,128 +554,154 @@ gconf_key_editor_init (GConfKeyEditor *editor)
 				NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (editor), GTK_RESPONSE_OK);
 	
+	gtk_container_set_border_width (GTK_CONTAINER (editor), 5);
+	gtk_dialog_set_has_separator (GTK_DIALOG (editor), FALSE);
+	gtk_window_set_resizable (GTK_WINDOW (editor), FALSE);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (editor)->vbox), 2);
+
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (editor)->vbox), vbox, TRUE, TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+	gtk_widget_show_all (vbox);
+
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
 	
-	editor->path_box = gtk_hbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (editor->path_box), 8);
-	label = gtk_label_new (_("Key path:"));
+	editor->path_box = gtk_hbox_new (FALSE, 12);
+	label = gtk_label_new (_("Path:"));
 	gtk_size_group_add_widget (size_group, label);
-	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (editor->path_box), label, FALSE, FALSE, 4);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (editor->path_box), label, FALSE, FALSE, 0);
 	editor->path_label = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (editor->path_label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (editor->path_box), editor->path_label, TRUE, TRUE, 4);
+	gtk_box_pack_start (GTK_BOX (editor->path_box), editor->path_label, TRUE, TRUE, 0);
 	gtk_widget_show_all (editor->path_box);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (editor)->vbox), editor->path_box, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), editor->path_box, FALSE, FALSE, 0);
 
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 8);
-	label = gtk_label_new_with_mnemonic (_("Key _name:"));
+	hbox = gtk_hbox_new (FALSE, 12);
+	label = gtk_label_new_with_mnemonic (_("_Name:"));
 	gtk_size_group_add_widget (size_group, label);
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 4);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	editor->name_entry = gtk_entry_new ();
+	gtk_widget_set_usize (editor->name_entry, 250, -1);
 	gtk_entry_set_activates_default (GTK_ENTRY (editor->name_entry), TRUE);
-	gtk_box_pack_start (GTK_BOX (hbox), editor->name_entry, TRUE, TRUE, 4);
+	gtk_box_pack_start (GTK_BOX (hbox), editor->name_entry, TRUE, TRUE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->name_entry);
 	gtk_widget_show_all (hbox);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (editor)->vbox), hbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-	frame = gtk_frame_new (NULL);
-
-	hbox = gtk_hbox_new (FALSE, 2);
+	hbox = gtk_hbox_new (FALSE, 12);
 	label = gtk_label_new_with_mnemonic (_("_Type:"));
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
-	editor->option_menu = gconf_key_editor_create_option_menu (editor);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_size_group_add_widget (size_group, label);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	editor->combobox = gconf_key_editor_create_combo_box (editor);
 	gtk_box_pack_start (GTK_BOX (hbox),
-			    editor->option_menu,
-			    FALSE, FALSE, 2);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->option_menu);
+			    editor->combobox,
+			    TRUE, TRUE, 0);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->combobox);
 	gtk_widget_show_all (hbox);
-	gtk_frame_set_label_widget (GTK_FRAME (frame), hbox);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
 	framebox = gtk_vbox_new (FALSE, 6);
 	gtk_widget_show (framebox);
-	gtk_container_add (GTK_CONTAINER (frame), framebox);
+	gtk_box_pack_start (GTK_BOX (vbox), framebox, FALSE, FALSE, 0);
 
-	editor->non_writable_label = gtk_hbox_new (FALSE, 3);
+	editor->non_writable_label = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (framebox), editor->non_writable_label, FALSE, FALSE, 0);
 
 	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_BUTTON);
 	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (editor->non_writable_label), image, FALSE, FALSE, 3);
+	gtk_box_pack_start (GTK_BOX (editor->non_writable_label), image, FALSE, FALSE, 0);
 
 	label = gtk_label_new (_("This key is not writable"));
 	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (editor->non_writable_label), label, FALSE, FALSE, 3);
-
-	editor->notebook = gtk_notebook_new ();
-	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (editor->notebook),
-				    FALSE);
-	gtk_notebook_set_show_border (GTK_NOTEBOOK (editor->notebook),
-				      FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (editor->notebook), 3);
-	gtk_box_pack_start (GTK_BOX (framebox), editor->notebook, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (editor->non_writable_label), label, FALSE, FALSE, 0);
 
 	editor->active_type = EDIT_INTEGER;
 
-	/* These have to be ordered such that the EDIT_ enum matches
-	 * the page indices
-	 */
-
 	/* EDIT_INTEGER */
-	value_box = gtk_hbox_new (FALSE, 0);
-	label = gtk_label_new_with_mnemonic (_("Key _value:"));
+	editor->int_box = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (editor->int_box), label, FALSE, FALSE, 0);
+
+	label = gtk_label_new_with_mnemonic (_("_Value:"));
 	editor->int_widget = gtk_spin_button_new_with_range (G_MININT, G_MAXINT, 1);
 
 	/* Set a nicer default value */
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (editor->int_widget), 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->int_widget);
-	gtk_box_pack_start (GTK_BOX (value_box), label, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (value_box), editor->int_widget, TRUE, TRUE, 0);
-	gtk_notebook_append_page (GTK_NOTEBOOK (editor->notebook),
-				  value_box, NULL);
-
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), editor->int_widget, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (editor->int_box), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), editor->int_box, FALSE, FALSE, 0);
+	gtk_widget_show_all (editor->int_box);
+	
 	/* EDIT_BOOLEAN */
-	value_box = gtk_hbox_new (FALSE, 0);
-	label = gtk_label_new_with_mnemonic (_("Key _value:"));
+	editor->bool_box = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	label = gtk_label_new ("    ");
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (editor->bool_box), label, FALSE, FALSE, 0);
+	label = gtk_label_new_with_mnemonic (_("_Value:"));
 	editor->bool_widget = gtk_toggle_button_new_with_mnemonic (_("_False"));
 	g_signal_connect (editor->bool_widget, "toggled",
 			  G_CALLBACK (bool_button_toggled),
 			  editor);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->bool_widget);
-	gtk_box_pack_start (GTK_BOX (value_box), label, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (value_box), editor->bool_widget, TRUE, TRUE, 0);
-	gtk_notebook_append_page (GTK_NOTEBOOK (editor->notebook),
-				  value_box, NULL);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), editor->bool_widget, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (editor->bool_box), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), editor->bool_box, FALSE, FALSE, 0);
+	gtk_widget_show_all (hbox);
+	gtk_widget_hide (editor->bool_box);
 
 	/* EDIT_STRING */
-	value_box = gtk_hbox_new (FALSE, 0);
-	label = gtk_label_new_with_mnemonic (_("Key _value:"));
+	editor->string_box = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	label = gtk_label_new ("    ");
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (editor->string_box), label, FALSE, FALSE, 0);
+	label = gtk_label_new_with_mnemonic (_("_Value:"));
 	editor->string_widget = gtk_entry_new ();
 	gtk_entry_set_activates_default (GTK_ENTRY (editor->string_widget), TRUE);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->string_widget);	
-	gtk_box_pack_start (GTK_BOX (value_box), label, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (value_box), editor->string_widget, TRUE, TRUE, 0);
-	gtk_notebook_append_page (GTK_NOTEBOOK (editor->notebook),
-				  value_box, NULL);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), editor->string_widget, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (editor->string_box), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), editor->string_box, FALSE, FALSE, 0);
+	gtk_widget_show_all (hbox);
+	gtk_widget_hide (editor->string_box);
 
-	/* EDIT_INTEGER */
-	value_box = gtk_hbox_new (FALSE, 0);
-	label = gtk_label_new_with_mnemonic (_("Key _value:"));
+	/* EDIT_FLOAT */
+	editor->float_box = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	label = gtk_label_new ("    ");
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (editor->float_box), label, FALSE, FALSE, 0);
+	label = gtk_label_new_with_mnemonic (_("_Value:"));
 	editor->float_widget = gtk_spin_button_new_with_range (G_MINFLOAT, G_MAXFLOAT, 0.1);
 
 	/* Set a nicer default value */
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (editor->float_widget), 0.0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->float_widget);
-	gtk_box_pack_start (GTK_BOX (value_box), label, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (value_box), editor->float_widget, TRUE, TRUE, 0);
-	gtk_notebook_append_page (GTK_NOTEBOOK (editor->notebook),
-				  value_box, NULL);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), editor->float_widget, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (editor->float_box), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), editor->float_box, FALSE, FALSE, 0);
+	gtk_widget_show_all (hbox);
+	gtk_widget_hide (editor->float_box);
 
         /* EDIT_LIST */
-        value_box = gtk_vbox_new (FALSE, 3);
+	editor->list_box = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	label = gtk_label_new ("    ");
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (editor->list_box), label, FALSE, FALSE, 0);
 
-	hbox = gtk_hbox_new (FALSE, 3);
+        value_box = gtk_vbox_new (FALSE, 6);
+
+	hbox = gtk_hbox_new (FALSE, 12);
 	label = gtk_label_new_with_mnemonic (_("List _type:"));
 	editor->list_type_menu = gconf_key_editor_create_list_type_menu (editor);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->list_type_menu);
@@ -677,10 +710,10 @@ gconf_key_editor_init (GConfKeyEditor *editor)
         gtk_box_pack_start (GTK_BOX (hbox),
                             editor->list_type_menu, TRUE, TRUE, 0);
 
-	label = gtk_label_new_with_mnemonic (_("Key _value:"));
+	label = gtk_label_new_with_mnemonic (_("_Values:"));
 	gtk_misc_set_alignment(GTK_MISC (label), 0.0, 0.5);
   
-	hbox = gtk_hbox_new (FALSE, 3);
+	hbox = gtk_hbox_new (FALSE, 12);
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
@@ -705,13 +738,13 @@ gconf_key_editor_init (GConfKeyEditor *editor)
 
 	button_box = gtk_vbutton_box_new ();
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (button_box), GTK_BUTTONBOX_START);
-	gtk_box_set_spacing (GTK_BOX (button_box), 3);
+	gtk_box_set_spacing (GTK_BOX (button_box), 6);
 	button = gtk_button_new_from_stock (GTK_STOCK_ADD);
 	fix_button_align (button);
 	editor->remove_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
 	fix_button_align (editor->remove_button);
-	/* FIXME: We should have a stock edit button */
-	editor->edit_button = gtk_button_new_with_mnemonic ("_Edit");
+	editor->edit_button = gtk_button_new_from_stock (GTK_STOCK_EDIT);
+	fix_button_align (editor->edit_button);
 	editor->go_up_button = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
 	fix_button_align (editor->go_up_button);
 	editor->go_down_button = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
@@ -740,13 +773,10 @@ gconf_key_editor_init (GConfKeyEditor *editor)
         gtk_box_pack_start (GTK_BOX (hbox), sw, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), button_box, FALSE, FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (sw), editor->list_widget);
-  	gtk_notebook_append_page (GTK_NOTEBOOK (editor->notebook),
-  				  value_box, NULL);
-
-	gtk_container_set_border_width (GTK_CONTAINER (frame), 8);
-	gtk_container_set_border_width (GTK_CONTAINER (editor->notebook), 8);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (editor)->vbox), frame, TRUE, TRUE, 8);
-	gtk_widget_show_all (frame);
+	gtk_box_pack_start (GTK_BOX (editor->list_box), value_box, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), editor->list_box, TRUE, TRUE, 0);
+	gtk_widget_show_all (value_box);
+	gtk_widget_hide (editor->list_box);
 }
 
 GType
@@ -782,11 +812,11 @@ gconf_key_editor_new (GConfKeyEditorAction action)
 
 	switch (action) {
 	case GCONF_KEY_EDITOR_NEW_KEY:
-		gtk_window_set_title (GTK_WINDOW (dialog), _("New key"));
+		gtk_window_set_title (GTK_WINDOW (dialog), _("New Key"));
 		gtk_widget_grab_focus (dialog->name_entry);
 		break;
 	case GCONF_KEY_EDITOR_EDIT_KEY:
-		gtk_window_set_title (GTK_WINDOW (dialog), _("Edit key"));
+		gtk_window_set_title (GTK_WINDOW (dialog), _("Edit Key"));
 
 		gtk_widget_set_sensitive (dialog->name_entry, FALSE);
 		gtk_widget_hide (dialog->path_box);
@@ -806,24 +836,24 @@ gconf_key_editor_set_value (GConfKeyEditor *editor, GConfValue *value)
 		return;
 	}
 
-	gtk_widget_set_sensitive (editor->option_menu, FALSE);
+	gtk_widget_set_sensitive (editor->combobox, FALSE);
 	gtk_widget_set_sensitive (editor->list_type_menu, FALSE);
 
 	switch (value->type) {
 	case GCONF_VALUE_INT:
-		gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_INTEGER);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_INTEGER);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (editor->int_widget), gconf_value_get_int (value));
 		break;
 	case GCONF_VALUE_STRING:
-		gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_STRING);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_STRING);
 		gtk_entry_set_text (GTK_ENTRY (editor->string_widget), gconf_value_get_string (value));
 		break;
 	case GCONF_VALUE_BOOL:
-		gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_BOOLEAN);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_BOOLEAN);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->bool_widget), gconf_value_get_bool (value));
 		break;
 	case GCONF_VALUE_FLOAT:
-		gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_FLOAT);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_FLOAT);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (editor->float_widget), gconf_value_get_float (value));
 		break;
 	case GCONF_VALUE_LIST:
@@ -832,22 +862,22 @@ gconf_key_editor_set_value (GConfKeyEditor *editor, GConfValue *value)
 			
 			switch (gconf_value_get_list_type(value)) {
 				case GCONF_VALUE_INT:
-					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_INTEGER);
+					gtk_combo_box_set_active (GTK_COMBO_BOX (editor->list_type_menu), EDIT_INTEGER);
 					break;
 				case GCONF_VALUE_FLOAT:
-					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_FLOAT);
+					gtk_combo_box_set_active (GTK_COMBO_BOX (editor->list_type_menu), EDIT_FLOAT);
 					break;
 				case GCONF_VALUE_STRING:
-					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_STRING);
+					gtk_combo_box_set_active (GTK_COMBO_BOX (editor->list_type_menu), EDIT_STRING);
 					break;
 				case GCONF_VALUE_BOOL:
-					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_BOOLEAN);
+					gtk_combo_box_set_active (GTK_COMBO_BOX (editor->list_type_menu), EDIT_BOOLEAN);
 					break;
 				default:
 					g_assert_not_reached ();
 			}
 
-			gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_LIST);
+			gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_LIST);
 				
 		        while (iter != NULL) {
 				GConfValue* element = (GConfValue*) iter->data;
@@ -920,7 +950,7 @@ gconf_key_editor_get_value (GConfKeyEditor *editor)
 
 			value = gconf_value_new (GCONF_VALUE_LIST);
 
-			switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+			switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 			        case EDIT_INTEGER:
 					gconf_value_set_list_type (value, GCONF_VALUE_INT);
 					break;
@@ -961,7 +991,11 @@ gconf_key_editor_set_writable (GConfKeyEditor *editor, gboolean writable)
 	else
 		gtk_widget_show (editor->non_writable_label);
 
-	gtk_widget_set_sensitive (editor->notebook, writable);
+	gtk_widget_set_sensitive (editor->bool_box, writable);
+	gtk_widget_set_sensitive (editor->int_box, writable);
+	gtk_widget_set_sensitive (editor->float_box, writable);
+	gtk_widget_set_sensitive (editor->list_box, writable);
+	gtk_widget_set_sensitive (editor->string_box, writable);
 }
 
 G_CONST_RETURN char *
